<?php

namespace Litecms\Bets\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Bets\Http\Requests\BetsRequest;
use Litecms\Bets\Interfaces\BetsRepositoryInterface;
use Litecms\Bets\Models\Bets;

/**
 * Resource controller class for bets.
 */
class BetsResourceController extends BaseController
{

    /**
     * Initialize bets resource controller.
     *
     * @param type BetsRepositoryInterface $bets
     *
     * @return null
     */
    public function __construct(BetsRepositoryInterface $bets)
    {
        parent::__construct();
        $this->repository = $bets;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Bets\Repositories\Criteria\BetsResourceCriteria::class);
    }

    /**
     * Display a list of bets.
     *
     * @return Response
     */
    public function index(BetsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Bets\Repositories\Presenter\BetsPresenter::class)
                ->$function();
        }

        $bets = $this->repository->paginate();

        return $this->response->title(trans('bets::bets.names'))
            ->view('bets::bets.index', true)
            ->data(compact('bets'))
            ->output();
    }

    /**
     * Display bets.
     *
     * @param Request $request
     * @param Model   $bets
     *
     * @return Response
     */
    public function show(BetsRequest $request, Bets $bets)
    {

        if ($bets->exists) {
            $view = 'bets::bets.show';
        } else {
            $view = 'bets::bets.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('bets::bets.name'))
            ->data(compact('bets'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new bets.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BetsRequest $request)
    {

        $bets = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('bets::bets.name')) 
            ->view('bets::bets.create', true) 
            ->data(compact('bets'))
            ->output();
    }

    /**
     * Create new bets.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BetsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $bets                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('bets::bets.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('bets/bets/' . $bets->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/bets/bets'))
                ->redirect();
        }

    }

    /**
     * Show bets for editing.
     *
     * @param Request $request
     * @param Model   $bets
     *
     * @return Response
     */
    public function edit(BetsRequest $request, Bets $bets)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('bets::bets.name'))
            ->view('bets::bets.edit', true)
            ->data(compact('bets'))
            ->output();
    }

    /**
     * Update the bets.
     *
     * @param Request $request
     * @param Model   $bets
     *
     * @return Response
     */
    public function update(BetsRequest $request, Bets $bets)
    {
        try {
            $attributes = $request->all();

            $bets->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('bets::bets.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('bets/bets/' . $bets->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('bets/bets/' . $bets->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the bets.
     *
     * @param Model   $bets
     *
     * @return Response
     */
    public function destroy(BetsRequest $request, Bets $bets)
    {
        try {

            $bets->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('bets::bets.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('bets/bets/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('bets/bets/' . $bets->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple bets.
     *
     * @param Model   $bets
     *
     * @return Response
     */
    public function delete(BetsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('bets::bets.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('bets/bets'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/bets/bets'))
                ->redirect();
        }

    }

    /**
     * Restore deleted bets.
     *
     * @param Model   $bets
     *
     * @return Response
     */
    public function restore(BetsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('bets::bets.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/bets/bets'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/bets/bets/'))
                ->redirect();
        }

    }

}
